library

package module
v1.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 1, 2026 License: BSD-3-Clause Imports: 1 Imported by: 0

README

Go Doc Release Go Report Card Build Status Sourcegraph

logo

Getting Started

// TODO: replace me

Installation

# TODO: replace me
go get -v github.com/rizalgowandy/library-template-go

Quick Start

// TODO: replace me

For more example check here.

Test Double / Stub

Sometimes it's make sense to make an API call without actually calling the API. In order to support that this library has a built-in stub that can be triggered. You can enable stub by injecting certain value to the context data. You can also enforce that certain API call will always return error with specific type and message.

// TODO: replace me

For more example, check here.

Supported API

Version: // TODO: replace me

Documentation

Overview

TODO: replace me

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
}

TODO: replace me Client is the main client to interact with XYZ API.

func NewClient

func NewClient(cfg api.Config) (*Client, error)

TODO: replace me NewClient creates a client to interact with XYZ API.

Directories

Path Synopsis
pkg
api

Jump to